@@ -77,9 +77,9 @@ pub struct TxResultBlockMsg {
 #[allow(clippy::upper_case_acronyms)]
 #[derive(Deserialize, Serialize, Debug)]
 pub struct TxBlockMsgInner {
-    pub sender: String,
-    pub contract: String,
-    pub execute_msg: Value,
+    pub sender: Option<String>,
+    pub contract: Option<String>,
+    pub execute_msg: Option<Value>,
 }
 #[allow(clippy::upper_case_acronyms)]
 #[derive(Deserialize, Serialize, Debug)]
